@@ -9,7 +9,6 @@ pub struct Py_complex {
     pub imag: c_double
 }
 
-#[link(name = "python2.7")]
 extern "C" {
     pub fn _Py_c_sum(left: Py_complex, right: Py_complex) -> Py_complex;
     pub fn _Py_c_diff(left: Py_complex, right: Py_complex) -> Py_complex;
@@ -23,16 +22,15 @@ extern "C" {
 #[repr(C)]
 #[derive(Copy, Clone)]
 pub struct PyComplexObject {
-    #[cfg(feature="Py_TRACE_REFS")]
+    #[cfg(py_sys_config="Py_TRACE_REFS")]
     pub _ob_next: *mut PyObject,
-    #[cfg(feature="Py_TRACE_REFS")]
+    #[cfg(py_sys_config="Py_TRACE_REFS")]
     pub _ob_prev: *mut PyObject,
     pub ob_refcnt: Py_ssize_t,
     pub ob_type: *mut PyTypeObject,
     pub cval: Py_complex
 }
 
-#[link(name = "python2.7")]
 extern "C" {
     pub static mut PyComplex_Type: PyTypeObject;
 }
@@ -48,7 +46,6 @@ pub unsafe fn PyComplex_CheckExact(op : *mut PyObject) -> c_int {
     (Py_TYPE(op) == u) as c_int
 }
 
-#[link(name = "python2.7")]
 extern "C" {
     pub fn PyComplex_FromCComplex(v: Py_complex) -> *mut PyObject;
     pub fn PyComplex_FromDoubles(real: c_double,
