@@ -5,16 +5,15 @@ use object::*;
 #[repr(C)]
 #[derive(Copy, Clone)]
 struct PyFloatObject {
-    #[cfg(feature="Py_TRACE_REFS")]
+    #[cfg(py_sys_config="Py_TRACE_REFS")]
     pub _ob_next: *mut PyObject,
-    #[cfg(feature="Py_TRACE_REFS")]
+    #[cfg(py_sys_config="Py_TRACE_REFS")]
     pub _ob_prev: *mut PyObject,
     pub ob_refcnt: Py_ssize_t,
     pub ob_type: *mut PyTypeObject,
     pub ob_fval: c_double
 }
 
-#[link(name = "python2.7")]
 extern "C" {
     pub static mut PyFloat_Type: PyTypeObject;
 }
@@ -32,7 +31,6 @@ pub unsafe fn PyFloat_CheckExact(op : *mut PyObject) -> c_int {
 
 pub const PyFloat_STR_PRECISION : c_int = 12;
 
-#[link(name = "python2.7")]
 extern "C" {
     pub fn PyFloat_FromString(str: *mut PyObject,
                               pend: *mut *mut c_char)
