@@ -5,9 +5,9 @@ use object::*;
 #[repr(C)]
 #[derive(Copy, Clone)]
 pub struct PyTupleObject {
-    #[cfg(feature="Py_TRACE_REFS")]
+    #[cfg(py_sys_config="Py_TRACE_REFS")]
     pub _ob_next: *mut PyObject,
-    #[cfg(feature="Py_TRACE_REFS")]
+    #[cfg(py_sys_config="Py_TRACE_REFS")]
     pub _ob_prev: *mut PyObject,
     pub ob_refcnt: Py_ssize_t,
     pub ob_type: *mut PyTypeObject,
@@ -15,7 +15,6 @@ pub struct PyTupleObject {
     pub ob_item: [*mut PyObject; 1],
 }
 
-#[link(name = "python2.7")]
 extern "C" {
     pub static mut PyTuple_Type: PyTypeObject;
 }
@@ -49,7 +48,6 @@ pub unsafe fn PyTuple_SET_ITEM(op: *mut PyObject, i: Py_ssize_t, v: *mut PyObjec
    *(*(op as *mut PyTupleObject)).ob_item.as_mut_ptr().offset(i as isize) = v;
 }
 
-#[link(name = "python2.7")]
 extern "C" {
     pub fn PyTuple_New(size: Py_ssize_t) -> *mut PyObject;
     pub fn PyTuple_Size(p: *mut PyObject) -> Py_ssize_t;
